
sncosmo.TimeSeriesModel
=======================

.. currentmodule:: sncosmo

.. autoclass:: TimeSeriesModel
   :show-inheritance:

   
   
   .. rubric:: Attributes

   .. autosummary::
   
         cosmo
         params
         parnames
         refband
         refmagsys
         refphase
   
   


   
   
   .. rubric:: Methods Summary

   .. autosummary::
   
      ~TimeSeriesModel.__call__
      ~TimeSeriesModel.bandflux
      ~TimeSeriesModel.bandmag
      ~TimeSeriesModel.bandoverlap
      ~TimeSeriesModel.disp
      ~TimeSeriesModel.flux
      ~TimeSeriesModel.set
      ~TimeSeriesModel.set_bandflux_relative_error
      ~TimeSeriesModel.set_extinction_func
      ~TimeSeriesModel.times
   
   


   
   

   .. rubric:: Methods Documentation

   
   .. automethod:: __call__
   .. automethod:: bandflux
   .. automethod:: bandmag
   .. automethod:: bandoverlap
   .. automethod:: disp
   .. automethod:: flux
   .. automethod:: set
   .. automethod:: set_bandflux_relative_error
   .. automethod:: set_extinction_func
   .. automethod:: times

   
   